@@ -71,7 +71,16 @@ def check_input_range(
         )
 
 
-def interpolate(grid_name, luminosity, teff_new, tinner_new, tau_new, distance_in_kpc):
+def interpolate(
+    grid_name,
+    luminosity,
+    teff_new,
+    tinner_new,
+    tau_new,
+    distance_in_kpc,
+    custom_output_name,
+    print_outputs,
+):
     """A script for returning a model within any grid or returning an interpolated
     model that fits within the given parameter space. The interpolation interpolates
     over the flux at each wavelength in the model grid.
@@ -90,6 +99,10 @@ def interpolate(grid_name, luminosity, teff_new, tinner_new, tau_new, distance_i
         optical depth specified at 10 microns.
     distance_in_kpc : float
         Distance in kpc.
+    custom_output_name: str
+        Custom name for output in save_model_spectrum.
+    print_outputs : bool
+        Whether to print output expansion velocities and mass loss rates.
 
     Returns
     -------
@@ -106,7 +119,7 @@ def interpolate(grid_name, luminosity, teff_new, tinner_new, tau_new, distance_i
     scaling_factor = ((float(distance_in_kpc) / u.AU.to(u.kpc)) ** 2) / 1379
 
     # gets models
-    grid_dusty, grid_outputs = get_models.get_model_grid(grid_name)
+    grid_dusty, grid_outputs = get_models.get_model_grid(grid_name, respond=False)
     waves = grid_dusty[0][0]
 
     # create interpolator
@@ -118,7 +131,8 @@ def interpolate(grid_name, luminosity, teff_new, tinner_new, tau_new, distance_i
 
     # if model already exists
     if (teff_new in teff) & (tinner_new in tinner) & (tau_new in tau):
-        print("Model exists:")
+        if print_outputs == True:
+            print("Model exists:")
         ind = np.where(
             (grid_outputs["teff"] == teff_new)
             & (grid_outputs["tinner"] == tinner_new)
@@ -182,19 +196,24 @@ def interpolate(grid_name, luminosity, teff_new, tinner_new, tau_new, distance_i
             [waves, scaled_fluxes], names=("wavelength_um", "flux_wm2")
         )
 
-    print("\nExpansion velocity = " + "%.2f" % float(expansion_velocity) + " km/s")
-    print("Gas mass-loss rate = " + "%.3E" % float(mass_loss_rate) + " Msun/yr\n")
+    if print_outputs == True:
+        print("\nExpansion velocity = " + "%.2f" % float(expansion_velocity) + " km/s")
+        print("Gas mass-loss rate = " + "%.3E" % float(mass_loss_rate) + " Msun/yr\n")
 
     scaled_model.write(
-        grid_name
+        custom_output_name
         + "_"
-        + str(luminosity)
+        + grid_name
         + "_"
-        + str(teff_new)
+        + str(int(luminosity))
         + "_"
-        + str(tinner_new)
+        + str(int(teff_new))
+        + "_"
+        + str(int(tinner_new))
         + "_"
         + str(tau_new)
+        + "_"
+        + str(int(distance_in_kpc))
         + ".csv",
         overwrite=True,
     )
