@@ -6,7 +6,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 from fnmatch import fnmatch
 from astropy.table import Table
-from desk.set_up import get_data
+from desk.set_up import get_data, config, get_models
 
 sns.set_palette("colorblind")
 
@@ -124,11 +124,21 @@ def get_model_and_data_for_plotting(
     grid_dusty = Table.read(
         full_path + "models/" + str(input_file["grid_name"][0]) + "_models.hdf5"
     )
-
+    grid_outputs = Table.read(
+        full_path + "models/" + str(input_file["grid_name"][0]) + "_outputs.hdf5"
+    )
     x_data, y_data = get_data.get_values(target["file_name"])
-    x_model_init, y_model_init = grid_dusty[
-        target["number"] - 1
-    ]  # model_id starts at 1
+
+    if target["grid_name"] in config.external_grids:
+        correct_index = get_models.get_model_index_using_number(
+            target["grid_name"], grid_outputs, target["number"]
+        )
+    else:
+        correct_index = get_models.get_model_index_using_number(
+            target["grid_name"], grid_outputs, target["number"], target["grid_idx"]
+        )
+
+    x_model_init, y_model_init = grid_dusty[correct_index]
 
     x_model_select = x_model_init[np.where(y_model_init != 0)]
     y_model_select = y_model_init[np.where(y_model_init != 0)]
@@ -301,7 +311,7 @@ def create_fig(source_path, source_filename, dest_path, save_name, flux):
         fig.savefig(dest_path + "/" + save_name, dpi=200, bbox_inches="tight")
         plt.close()
     else:
-        single_figures(source_path, source_filename, dest_path)
+        single_figures(source_path, source_filename, dest_path, flux)
 
 
 # if __name__ == "__main__":
