@@ -6,25 +6,22 @@ path = str(__file__.replace("set_up/config.py", ""))
 fitting = dict(
     lum_min=1000,
     lum_max=150000,
-    default_grid="Oss-Orich-bb",
+    default_grid="silicates",
     default_wavelength_min=0.01,
     default_wavelength_max=1000,
     default_number_of_times_to_scale_models=50,
 )
 output = dict(printed_output="True", output_unit="Wm^-2", create_figure="yes")
 grids = [
-    "Crystalline-20-bb",
-    "Oss-Orich-aringer",
-    "Oss-Orich-bb",
-    "Zubko-Crich-aringer",
-    "Zubko-Crich-bb",
-    "arnold-palmer",
-    "big-grains",
-    "corundum-20-bb",
-    "fifth-iron",
-    "half-iron",
-    "one-fifth-carbon",
-    "desk-mix",
+    "amorphous-carbon",
+    "silicates",
+    "carbon-mix",
+    "corundum-mix",
+    "crystalline-mix",
+    "draine-mix",
+    "iron-mix",
+    "o-def-silicates",
+    "silicate-mix",
 ]
 external_grids = [
     "H11-LMC",
