@@ -46,7 +46,7 @@ def get_remote_models(model_grid_name):
 
     """
     # update if zeonodo repository updated
-    repository = 4776833
+    repository = 5912191
 
     fname_dld_outputs = download_file(
         "https://zenodo.org/record/"
@@ -72,7 +72,7 @@ def get_remote_models(model_grid_name):
     # \n Padova options: J400, J1000, H11, R12, R13'
 
 
-def check_models(model_grid, size_filename="desk_model_grid_sizes.csv"):
+def check_models(model_grid, respond, size_filename="desk_model_grid_sizes.csv"):
 
     """
     Checks if model grids are available and returns the full path to the model.
@@ -82,6 +82,8 @@ def check_models(model_grid, size_filename="desk_model_grid_sizes.csv"):
     ----------
     model_grid : str
         Name of model grid to use.
+    respond: Bool
+        Whether to print if models were found.
 
     Returns
     -------
@@ -97,16 +99,18 @@ def check_models(model_grid, size_filename="desk_model_grid_sizes.csv"):
 
     # Checks if grid is available
     if os.path.isfile(outputs_file) and os.path.isfile(models_file):
-        print("\nYou already have the grid!\n")
+        if respond == True:
+            print("\nYou already have the grid!\n")
 
     else:
         # asks if you want to download the models
-        print("Models not found locally")
+        if respond == True:
+            print("Models not found locally")
         get_remote_models(model_grid)
     return (outputs_file, models_file)
 
 
-def get_model_grid(grid, testing=False):
+def get_model_grid(grid, testing=False, respond=True):
     """
     Gets the real model grid name if the defaults were chosen,and runs check_models.
 
@@ -116,6 +120,8 @@ def get_model_grid(grid, testing=False):
         Model grid name.
     testing: str
         Flag for testing that returns small grid (3 rows)
+    respond: Bool
+        Whether to print if models were found.
 
     Returns
     -------
@@ -127,24 +133,101 @@ def get_model_grid(grid, testing=False):
         The model grid parameters corresponding to the grid_dusty model grids
     """
 
+    def return_model_grid(_model_grid_name, testing, respond):
+        """Checks models and returns model grid and outputs.
+
+        Parameters
+        ----------
+        _model_grid_name : str
+            Name of model grid.
+        testing : Bool
+            Whether this is a test.
+        respond: Bool
+            Whether to print if models were found.
+
+        Returns
+        -------
+        type
+            Description of returned object.
+
+        """
+        outputs_file_name, models_file_name = check_models(_model_grid_name, respond)
+        _grid_dusty = read_hdf5(models_file_name, testing)
+        _grid_dusty.rename_columns(["col0", "col1"], ["wavelength_um", "flux_wm2"])
+
+        _grid_outputs = read_hdf5(outputs_file_name, testing)
+        _grid_outputs.add_column(Column([1] * len(_grid_outputs), name="norm"))
+        return _grid_dusty, _grid_outputs
+
     # User input for models
     if grid == "carbon":
-        model_grid = "Zubko-Crich-bb"
+        grid_dusty, grid_outputs = return_model_grid(
+            "amorphous-carbon", testing, respond
+        )
     elif grid == "oxygen":
-        model_grid = "Oss-Orich-bb"
+        grid_dusty, grid_outputs = return_model_grid("silicates", testing, respond)
+    elif grid == "grams":
+        from astropy.table import vstack
+
+        # combine grams
+        grid_dusty_a, grid_outputs_a = return_model_grid(
+            "grams-oxygen", testing, respond
+        )
+        grid_dusty_b, grid_outputs_b = return_model_grid(
+            "grams-carbon", testing, respond
+        )
+
+        grid_dusty_a["wavelength_um"] = Column(
+            np.pad(grid_dusty_a["wavelength_um"], [(0, 0), (0, 19)])
+        )
+        grid_dusty_a["flux_wm2"] = Column(
+            np.pad(grid_dusty_a["flux_wm2"], [(0, 0), (0, 19)])
+        )
+        grid_dusty = vstack((grid_dusty_a, grid_dusty_b))
+        grid_outputs = vstack((grid_outputs_a, grid_outputs_b))
+
     else:
         if (grid in config.grids) | (grid in config.external_grids):
-            model_grid = grid
+            grid_dusty, grid_outputs = return_model_grid(grid, testing, respond)
         else:
             raise ValueError(
                 "\n\nUnknown grid. Please make another model selection.\n\n To see options use: desk grids or desk.grids() in python"
             )
-    outputs_file_name, models_file_name = check_models(model_grid)
-
-    grid_dusty = read_hdf5(models_file_name, testing)
-    grid_dusty.rename_columns(["col0", "col1"], ["wavelength_um", "flux_wm2"])
-
-    grid_outputs = read_hdf5(outputs_file_name, testing)
-    grid_outputs.add_column(Column([1] * len(grid_outputs), name="norm"))
 
     return grid_dusty, grid_outputs
+
+
+def get_model_index_using_number(
+    grid_name, grid_outputs, requested_grid_number, requested_grid_index=0
+):
+    """Returns the model_outputs index of a grid or external grid given.
+
+    Parameters
+    ----------
+    grid_name : str
+        Name of the desk grid for which you want a model.
+    grid_outputs : astropy table
+        outputs table read from the `*model*_outfits.hdf5` file.
+    requested_grid_number : int
+        `number` which is a column in the model_outputs. Number is unique for
+        external grids but not for regular grids.
+    requested_grid_index : int
+        `grid_idx` which is a column in the model_outputs. For grids, number and
+        grid_idx create unique identifier.
+
+    Returns
+    -------
+    correct_index: int
+        grid outputs index of correct model.
+
+    """
+    if grid_name in config.external_grids:
+        correct_index = np.where(grid_outputs["number"] == requested_grid_number)[0]
+    else:
+        correct_index = np.where(
+            (grid_outputs["number"] == requested_grid_number)
+            & (grid_outputs["grid_idx"] == requested_grid_index)
+        )[0]
+    if len(correct_index) > 1:
+        raise ValueError("Multiple models that match that criteria")
+    return correct_index[0]
