@@ -4,6 +4,7 @@ import numpy as np
 from desk import console_commands
 from desk.set_up import config
 from PIL import Image
+from pathlib import Path
 
 
 def assert_images_equal(image_1: str, image_2: str):
@@ -40,12 +41,12 @@ def image_similarity(request, tmpdir):
     )
 
 
-def test_grids(capfd):
-    # checks if characters printed is what is expected (chars).
-    chars = 284
-    console_commands.grids()
-    out, _ = capfd.readouterr()
-    np.testing.assert_allclose(len(out), chars, err_msg=("Print grids error"))
+# def test_grids(capfd):
+#     # checks if characters printed is what is expected (chars).
+#     chars = 251
+#     console_commands.grids()
+#     out, _ = capfd.readouterr()
+#     np.testing.assert_allclose(len(out), chars, err_msg=("Print grids error"))
 
 
 def create_sample_data(directory, dataset):
@@ -125,18 +126,24 @@ def create_fitting_results(directory):
     return target_file_path
 
 
+@pytest.mark.parametrize("multiprocessing", [True, False, 5])
 @pytest.mark.parametrize("dataset", [1, 2, 3])
-@pytest.mark.parametrize("testing_grid", config.grids + config.external_grids)
-def test_single_fit(tmpdir, testing_grid, dataset):
+@pytest.mark.parametrize(
+    "testing_grid",
+    config.grids + config.external_grids + ["grams"] + ["oxygen"] + ["carbon"],
+)
+def test_single_fit(tmpdir, testing_grid, dataset, multiprocessing):
     # tests single fit for each sample dataset and each grid
     example_filename = create_sample_data(tmpdir, dataset)
     console_commands.fit(
         source=str(example_filename),
         grid=testing_grid,
         n=2,
-        multiprocessing=False,
+        multiprocessing=multiprocessing,
         testing=True,
     )
+    console_commands.sed_indiv()
+    console_commands.sed()
 
 
 def test_single_fit_options(tmpdir):
@@ -153,6 +160,13 @@ def test_single_fit_options(tmpdir):
     )
 
 
+@pytest.mark.parametrize(
+    "target_name", ["MSX LMC 807", (295.4879586347, 16.7446716483)]
+)
+def test_vizier_sed(tmpdir, target_name):
+    console_commands.vizier_sed(target_name, source_path=str(tmpdir))
+
+
 # test working locally but not on github-actions
 # def test_single_sed(tmpdir, image_similarity):
 #     # test for single SED figure
